# finam-netCDF

FINAM components for reading and writing spatial and temporal data from and to [NetCFD](https://www.unidata.ucar.edu/software/netcdf/) files.

See the finam-netCDF [documentation](https://finam.pages.ufz.de/finam-netcdf).

## License

LGPLv3, Copyright © 2021-2023, the FINAM developers from Helmholtz-Zentrum für Umweltforschung GmbH - UFZ. All rights reserved.
